@@ -5,7 +5,7 @@ use parent 'Plack::Middleware';
 use Plack::Util::Accessor qw/callback psgix option action/;
 use Devel::TimeStats;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub prepare_app {
     my $self = shift;
@@ -43,12 +43,15 @@ sub call {
 
     my $res = $self->app->($env);
 
-    $env->{$self->psgix}->profile(
-        end => $action,
-    );
-
     $self->response_cb($res, sub {
         my $res = shift;
+
+        $env->{$self->psgix}->profile('end app');
+
+        $env->{$self->psgix}->profile(
+            end => $action,
+        );
+
         $self->callback->($env->{$self->psgix}, $env, $res);
         return;
     });
